Index: webrtc/api/objc/RTCRtpCodecParameters+Private.h |
diff --git a/webrtc/api/objc/RTCRtpParameters+Private.h b/webrtc/api/objc/RTCRtpCodecParameters+Private.h |
similarity index 61% |
copy from webrtc/api/objc/RTCRtpParameters+Private.h |
copy to webrtc/api/objc/RTCRtpCodecParameters+Private.h |
index e0370338f3b70a6057ed26d85879193368eada65..aabbf7d0a1bb73abf53ea77a0b18518d942969f3 100644 |
--- a/webrtc/api/objc/RTCRtpParameters+Private.h |
+++ b/webrtc/api/objc/RTCRtpCodecParameters+Private.h |
@@ -10,20 +10,20 @@ |
#import <Foundation/Foundation.h> |
-#import "webrtc/api/objc/RTCRtpParameters.h" |
+#import "webrtc/api/objc/RTCRtpCodecParameters.h" |
#include "webrtc/api/rtpparameters.h" |
NS_ASSUME_NONNULL_BEGIN |
-@interface RTCRtpParameters () |
+@interface RTCRtpCodecParameters () |
-/** Returns the equivalent native RtpParameters structure. */ |
-@property(nonatomic, readonly) webrtc::RtpParameters nativeParameters; |
+/** Returns the equivalent native RtpCodecParameters structure. */ |
+@property(nonatomic, readonly) webrtc::RtpCodecParameters nativeParameters; |
-/** Initialize the object with a native RtpParameters structure. */ |
+/** Initialize the object with a native RtpCodecParameters structure. */ |
- (instancetype)initWithNativeParameters: |
- (const webrtc::RtpParameters &)nativeParameters; |
+ (const webrtc::RtpCodecParameters &)nativeParameters; |
@end |